/* This .do file creates Appendix Table 5 */


	/* Notes:
	
	This .do file requires Stata 11. */
clear
version 11
clear matrix	
	
set scheme s1color
cap log close
log using "C:\Targeting_Indonesia\output\Tables\Appendix\Table5\AppdxT5.log",replace

****
* Do simulations for Ravallion for revision
****
local strata "povline_poor poor verypoor"
local subtractprogramcost = 1
local pmtcost = 1460
local commcost = 650
local hybcost = 1660
local numhhpervillage = 54
local shareRTS = 0.32
local programcostsmonths = 12

local distfineness = 30000
local expandfactor = 100 /*we expand the observations by a factor so that when we reassign the distn it is exactly the same*/
local transfortables = "0 50 100 200 500"
*local transfortables = "0 50"

local transferlb = 0
local transferub = 500
local transferunit = 5

use $data\simulation\data_sim,clear

replace poor = CONSUMPTION <= povline_poor if CONSUMPTION != . & povline_poor != .
replace verypoor = CONSUMPTION <= povline_verypoor if CONSUMPTION != . & povline_verypoor != .

egen stratum = group(`strata')

drop if CONSUMPTION == 0 | CONSUMPTION == .
keep if hhsize <= 9

g treatment = 1 if PMT == 1
replace treatment = 2 if COMMUNITY == 1
replace treatment = 3 if HYBRID == 1
label define treatment 1 "PMT" 2 "Community" 3 "Hybrid"
label var treatment treatment




* First, by RTS / treatment / POVLINE group: ensure same total weights so that we have the same weighted # of obs in each of these groups
* Then, within these groups, apply the PMT income distribution

* generate weights to make stratum / hhsize bins
egen stratumbinRTS = group(RTS povline_poor)
egen stratumbin = group(povline_poor)
bys treatment stratumbinRTS: egen numobsbin = count(stratumbin)
g tempnumobsPMT = numobsbin if treatment == 1
bys stratumbinRTS: egen numobsPMT = mean(tempnumobsPMT)
g double weight = numobsPMT/numobsbin

* next, figure out your percentil within group using cumul
* we'll expand to make the distributions more continuous
expand `expandfactor' 
bys treatment stratumbin: cumul CONSUMPTION [aw=weight], g(cdfnumber)
bys treatment stratumbin: egen mincumul = min(cdfnumber)
replace cdfnumber = (cdfnumber - mincumul) / (1-mincumul)


* next, use the CDF number to assign you a new consumption from the PMT distribution in your stratum
g pctile10000 = floor(cdfnumber*`distfineness')

preserve
collapse (max) hhsize-pctile10000, by(hhid)

drop cdfnumber mincumul pctile10000
bys stratumbin: cumul CONSUMPTION [aw=weight], g(cdfnumber)
bys stratumbin: egen mincumul = min(cdfnumber)
replace cdfnumber = (cdfnumber - mincumul) / (1-mincumul)
g pctile10000 = floor(cdfnumber*`distfineness')
count
local obscount = r(N)
local newobscount = `obscount' + `distfineness'
set obs `newobscount'
replace pctile10000 = _n - `obscount' if _n > `obscount'
cap drop _merge
fillin pctile10000 stratumbin 
sort stratumbin pctile10000
drop if stratumbin  == .
sort stratumbin pctile10000
by stratumbin pctile10000: g a = _N
by stratumbin : ipolate CONSUMPTION pctile10000, g(NEWCONS) 
tsset stratumbin  pctile10000
keep stratumbin pctile10000 NEWCONS
sort stratumbin  pctile1000
tempfile temp1
save `temp1'
restore

sort stratumbin  pctile10000
cap drop _merge
merge stratumbin pctile10000 using `temp1'
assert _merge != 1
keep if _merge == 3




bys treatment: summ CONSUMPTION NEWCONS hhsize RTS
bys treatment: summ CONSUMPTION NEWCONS hhsize RTS [aw=weight]
g hhid = _n
tempfile tempaccum
save `tempaccum'





* generate program cost
g programcost = `pmtcost' if treatment == 1
replace programcost = `commcost' if treatment == 2
replace programcost = `hybcost' if treatment == 3
replace programcost = programcost / `numhhpervillage'
replace programcost = programcost / `shareRTS'
replace programcost = programcost / `programcostsmonths'
bys treatment: summ programcost


quietly {

	
	* Calculate poverty impacts
	foreach transsize of num `transferlb'(`transferunit')`transferub' {
		noisily display `transsize'
		
		foreach povline of any verypoor  poor {
			preserve
			
			
			if `subtractprogramcost' == 1 {
				g cons_plus = NEWCONS+ (max(`transsize'-programcost,0)/hhsize) if RTS == 1
			}
			else {
				g cons_plus = NEWCONS+ (`transsize'/hhsize) if RTS == 1
			}
			replace cons_plus = NEWCONS if RTS == 0
			g headcount = 1 if cons_plus <= povline_`povline' & cons_plus != .
			replace headcount = 0 if cons_plus > povline_`povline' & cons_plus != .
			g povgap = (povline_`povline' - cons_plus) / povline_`povline' if cons_plus <= povline_`povline' & cons_plus != .
			replace povgap = 0 if cons_plus > povline_`povline' & cons_plus != .
			g povgap2 = povgap^2
			g povline = "`povline'"
			g transsize = `transsize'
			keep headcount* povgap* treatment hhid COMMUNITY HYBRID hhea transsize povline weight cons_plus NEWCONS RTS
			save `tempaccum'_`transsize'_`povline',replace
			restore
		}
	}	
}

/* TABLES */

* transfer size=0
use `tempaccum'_0_poor, clear
append using `tempaccum'_0_verypoor
for var headcount* povgap*: replace X = X * 100

g tempkeep = 0
for num `transfortables': replace tempkeep = 1 if transsize == X
keep if tempkeep == 1
table transsize treatment povline [aw=weight], c(mean headcount mean povgap mean povgap2) format(%03.2f)

* transfer size=50
use `tempaccum'_50_poor, clear
append using `tempaccum'_50_verypoor
for var headcount* povgap*: replace X = X * 100

g tempkeep = 0
for num `transfortables': replace tempkeep = 1 if transsize == X
keep if tempkeep == 1
table transsize treatment povline [aw=weight], c(mean headcount mean povgap mean povgap2) format(%03.2f)

* transfer size=100
use `tempaccum'_100_poor, clear
append using `tempaccum'_100_verypoor
for var headcount* povgap*: replace X = X * 100

g tempkeep = 0
for num `transfortables': replace tempkeep = 1 if transsize == X
keep if tempkeep == 1
table transsize treatment povline [aw=weight], c(mean headcount mean povgap mean povgap2) format(%03.2f)

* transfer size=200
use `tempaccum'_200_poor, clear
append using `tempaccum'_200_verypoor
for var headcount* povgap*: replace X = X * 100

g tempkeep = 0
for num `transfortables': replace tempkeep = 1 if transsize == X
keep if tempkeep == 1
table transsize treatment povline [aw=weight], c(mean headcount mean povgap mean povgap2) format(%03.2f)


* transfer size=500
use `tempaccum'_500_poor, clear
append using `tempaccum'_500_verypoor
for var headcount* povgap*: replace X = X * 100

g tempkeep = 0
for num `transfortables': replace tempkeep = 1 if transsize == X
keep if tempkeep == 1
table transsize treatment povline [aw=weight], c(mean headcount mean povgap mean povgap2) format(%03.2f)

log close
clear

/* TESTS FOR STATISTICAL SIGNIFICANCE AND CREATE FIGURE */

	/* The following commands require harddrive space between 4G and 20G, as large files are appended
	to run the loop and to produce Figure 2. */


/*
foreach transsize of num `transferlb'(`transferunit')`transferub'  {
	noisily display `transsize'

	foreach povline of any verypoor  poor {
		append using `tempaccum'_`transsize'_`povline'
	}
}
preserve
for var headcount* povgap*: replace X = X * 100

preserve
g tempkeep = 0
for num `transfortables': replace tempkeep = 1 if transsize == X
keep if tempkeep == 1
table transsize treatment povline [aw=weight], c(mean headcount mean povgap mean povgap2) format(%03.2f)

* test statistical significant
quietly {
	foreach transsize  of num `transfortables' {
		foreach povline of any poor verypoor {
			foreach Yvar of var headcount povgap povgap2* {
					noisily reg `Yvar' COMMUNITY HYBRID if transsize == `transsize' & povline == "`povline'", cluster(hhea)
					outreg2 using "$output\Tables\Table5\Table5", excel paren(se) bdec(3) append	
			}
		}

	}
}

restore


preserve
collapse headcount povgap povgap2 [aw=weight], by(treatment povline transsize)
ren povgap2 squarepovgap
label var transsize "Transfer size (Rp. 000s)"

reshape wide headcount povgap squarepovgap, i(povline transsize) j(treatment)
for var *1: label var X "PMT"
for var *2: label var X "Community"
for var *3: label var X "Hybrid"

foreach Yvar of any headcount povgap squarepovgap {
	foreach povline of any poor verypoor {
		twoway (line `Yvar'1 transsize if povline == "`povline'", lpattern(solid))  (line `Yvar'2 transsize if povline == "`povline'", lpattern(dash)) (line `Yvar'3 transsize if povline == "`povline'",lpattern(longdash)), title("`povline'") saving(`Yvar'_`povline'.gph,replace) legend(rows(1)) xsize(3.5) ysize(3.3)
		pause
	}
}

graph combine headcount_poor.gph headcount_verypoor.gph, title("Headcount ratio") saving(headcount.gph,replace) xsize(7) ysize(3.3)
graph combine povgap_poor.gph povgap_verypoor.gph, title("Poverty gap") saving(povgap.gph,replace) xsize(7) ysize(3.3)
graph combine squarepovgap_poor.gph squarepovgap_verypoor.gph, title("Squared poverty gap") saving(squarepovgap.gph,replace) xsize(7) ysize(3.3)

graph combine headcount.gph povgap.gph squarepovgap.gph, col(1) xsize(7) ysize(10) altshrink
graph export $output\Figures\Figure2\Figure2.eps,replace


restore

*/
	






	

